@@ -1,7 +1,8 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
-from math import isnan
+from datetime import datetime
+from math import isnan, isinf
 import sys
 
 VER = sys.version_info
@@ -27,12 +28,14 @@ else:
 def safe_string(value):
     """Safely and consistently format numeric values"""
     if isinstance(value, NUMERIC_TYPES):
-        if isnan(value):
+        if isnan(value) or isinf(value):
             value = ""
         else:
             value = "%.16g" % value
     elif value is None:
         value = "none"
+    elif isinstance(value, datetime):
+        value = value.isoformat()
     elif not isinstance(value, basestring):
         value = str(value)
     return value
