@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 from openpyxl.compat import unicode
 
@@ -19,7 +19,8 @@ from openpyxl.descriptors.excel import (
     HexBinary,
     TextPoint,
     Coordinate,
-    ExtensionList
+    ExtensionList,
+    Relation,
 )
 from openpyxl.descriptors.nested import (
     NestedInteger,
@@ -46,7 +47,7 @@ from openpyxl.descriptors.nested import NestedBool
 
 class EmbeddedWAVAudioFile(Serialisable):
 
-    name = Typed(expected_type=String, allow_none=True)
+    name = String(allow_none=True)
 
     def __init__(self,
                  name=None,
@@ -56,15 +57,21 @@ class EmbeddedWAVAudioFile(Serialisable):
 
 class Hyperlink(Serialisable):
 
-    invalidUrl = Typed(expected_type=String, allow_none=True)
-    action = Typed(expected_type=String, allow_none=True)
-    tgtFrame = Typed(expected_type=String, allow_none=True)
-    tooltip = Typed(expected_type=String, allow_none=True)
-    history = Typed(expected_type=Bool, allow_none=True)
-    highlightClick = Typed(expected_type=Bool, allow_none=True)
-    endSnd = Typed(expected_type=Bool, allow_none=True)
+    tagname = "hlinkClick"
+    namespace = DRAWING_NS
+
+    invalidUrl = String(allow_none=True)
+    action = String(allow_none=True)
+    tgtFrame = String(allow_none=True)
+    tooltip = String(allow_none=True)
+    history = Bool(allow_none=True)
+    highlightClick = Bool(allow_none=True)
+    endSnd = Bool(allow_none=True)
     snd = Typed(expected_type=EmbeddedWAVAudioFile, allow_none=True)
     extLst = Typed(expected_type=OfficeArtExtensionList, allow_none=True)
+    id = Relation(allow_none=True)
+
+    __elements__ = ('snd',)
 
     def __init__(self,
                  invalidUrl=None,
@@ -76,6 +83,7 @@ class Hyperlink(Serialisable):
                  endSnd=None,
                  snd=None,
                  extLst=None,
+                 id=None,
                 ):
         self.invalidUrl = invalidUrl
         self.action = action
@@ -85,7 +93,7 @@ class Hyperlink(Serialisable):
         self.highlightClick = highlightClick
         self.endSnd = endSnd
         self.snd = snd
-        self.extLst = extLst
+        self.id = id
 
 
 class Font(Serialisable):
@@ -94,9 +102,9 @@ class Font(Serialisable):
     namespace = DRAWING_NS
 
     typeface = String()
-    panose = Typed(expected_type=HexBinary, allow_none=True)
-    pitchFamily = Typed(expected_type=MinMax, allow_none=True)
-    charset = Typed(expected_type=MinMax, allow_none=True)
+    panose = HexBinary(allow_none=True)
+    pitchFamily = MinMax(min=0, max=52, allow_none=True)
+    charset = Integer(allow_none=True)
 
     def __init__(self,
                  typeface=None,
@@ -164,10 +172,10 @@ class CharacterProperties(Serialisable):
     uFillTx = EmptyTag()
     uFill = EmptyTag()
 
-    __elements__ = ('ln', 'highlight', 'latin', 'ea', 'cs', 'sym',
-                    'hlinkClick', 'hlinkMouseOver', 'rtl', 'noFill', 'solidFill', 'gradFill',
-                    'blipFill', 'pattFill', 'grpFill', 'effectLst', 'effectDag', 'uLnTx',
-                    'uLn', 'uFillTx', 'uFill')
+    __elements__ = ('ln', 'noFill', 'solidFill', 'gradFill', 'blipFill',
+                    'pattFill', 'grpFill', 'effectLst', 'effectDag', 'highlight','uLnTx',
+                    'uLn', 'uFillTx', 'uFill', 'latin', 'ea', 'cs', 'sym', 'hlinkClick',
+                    'hlinkMouseOver', 'rtl', )
 
     def __init__(self,
                  kumimoji=None,
@@ -279,8 +287,8 @@ class TabStopList(Serialisable):
 
 class Spacing(Serialisable):
 
-    spcPct = NestedInteger()
-    spcPts = NestedInteger()
+    spcPct = NestedInteger(allow_none=True)
+    spcPts = NestedInteger(allow_none=True)
 
     __elements__ = ('spcPct', 'spcPts')
 
@@ -471,14 +479,14 @@ class RegularTextRun(Serialisable):
 
     rPr = Typed(expected_type=CharacterProperties, allow_none=True)
     properties = Alias("rPr")
-    t = NestedText(expected_type=unicode, allow_none=True)
+    t = NestedText(expected_type=unicode)
     value = Alias("t")
 
     __elements__ = ('rPr', 't')
 
     def __init__(self,
                  rPr=None,
-                 t=None,
+                 t="",
                 ):
         self.rPr = rPr
         self.t = t
@@ -529,12 +537,12 @@ class Paragraph(Serialisable):
     pPr = Typed(expected_type=ParagraphProperties, allow_none=True)
     properties = Alias("pPr")
     endParaRPr = Typed(expected_type=CharacterProperties, allow_none=True)
-    r = Typed(expected_type=RegularTextRun, allow_none=True)
+    r = Sequence(expected_type=RegularTextRun)
     text = Alias('r')
     br = Typed(expected_type=LineBreak, allow_none=True)
     fld = Typed(expected_type=TextField, allow_none=True)
 
-    __elements__ = ('pPr', 'endParaRPr', 'r', 'br', 'fld')
+    __elements__ = ('pPr', 'r', 'br', 'fld', 'endParaRPr')
 
     def __init__(self,
                  pPr=None,
@@ -546,7 +554,7 @@ class Paragraph(Serialisable):
         self.pPr = pPr
         self.endParaRPr = endParaRPr
         if r is None:
-            r = RegularTextRun()
+            r = [RegularTextRun()]
         self.r = r
         self.br = br
         self.fld = fld
