@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 import datetime
 from io import BytesIO
@@ -182,7 +182,7 @@ class TestRead:
         wb = sample_workbook
         ws = wb['Sheet1 - Text']
         c1 = ws['A1']
-        c2 = ws.cell('A1')
+        c2 = ws['A1']
         assert c1 == c2
         assert c1.value == c2.value == 'This is cell A1 in Sheet 1'
 
@@ -265,7 +265,7 @@ def test_read_style_iter(tmpdir):
 
     wb = Workbook()
     ws = wb.worksheets[0]
-    cell = ws.cell('A1')
+    cell = ws['A1']
     cell.font = ft
 
     xlsx_file = "read_only_styles.xlsx"
@@ -356,7 +356,7 @@ def test_get_empty_cells_nonempty_row(datadir, DummyWorkbook, ReadOnlyWorksheet)
     Get row slice which only contains empty cells in a row containing non-empty
     cells earlier in the row.
     """
-    
+
     datadir.join("reader").chdir()
 
     src = b"""
@@ -368,7 +368,7 @@ def test_get_empty_cells_nonempty_row(datadir, DummyWorkbook, ReadOnlyWorksheet)
     </row>
     </sheetData>
     """
-    
+
     ws = ReadOnlyWorksheet(DummyWorkbook, "Sheet", "", "", [])
 
     xml = fromstring(src)
